@@ -13,7 +13,7 @@ use Moo;
 
 extends 'App::Office::Contacts::Database::Base';
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 
 # --------------------------------------------------
 
@@ -150,7 +150,7 @@ sub save_occupation_record
 
 	if ($context eq 'add')
 	{
-		$$occupation{id} = $$data{id} = $self -> db -> library -> insert_hash_get_id($table_name, $data);
+		$$occupation{id} = $$data{id} = $self -> db -> library -> insert_hashref_get_id($table_name, $data);
 	}
 	else
 	{
